@@ -3,9 +3,9 @@
 #ifndef _version_h_
 #define _version_h_
 
-#define MAJOR_VERSION 0
-#define MINOR_VERSION 94
+#define MAJOR_VERSION 1
+#define MINOR_VERSION 00
 
-#define RELEASE_DATE "April 13, 1994"
+#define RELEASE_DATE "May 6, 1999"
 
 #endif /* _version_h_ */
